#include <cvidef.h>

/*= Q8384 - Optical Spectrum Analyzes Include File ================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __avq8384_HEADER
#define __avq8384_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)
#define VI_ERROR_INSTR_PARAMETER16              (_VI_ERROR+0x3FFC0810L)
#define VI_ERROR_INSTR_PARAMETER17              (_VI_ERROR+0x3FFC0811L)
#define VI_ERROR_INSTR_PARAMETER18              (_VI_ERROR+0x3FFC0812L)     
/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define avq8384_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF0L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus CVIFUNC avq8384_Initialize (ViRsrc resourceName, ViBoolean IDQuery,
                                     ViBoolean resetDevice,
                                     ViSession *instrumentHandle);

ViStatus CVIFUNC avq8384_CntrWvlng_MenuSet (ViSession instrumentHandle,
                                            ViInt16 centerMode,
                                            ViBoolean xaxisMode,
                                            ViReal64 centerValue,
                                            ViBoolean autoPeak);


ViStatus CVIFUNC avq8384_WvLngSpn_MenuSet (ViSession instrumentHandle,
                                           ViInt16 spanMode, ViBoolean xaxisMode,
                                           ViReal64 value);

ViStatus CVIFUNC avq8384_XaxisMode_Set (ViSession instrumentHandle,
                                        ViBoolean xaxisMode);

ViStatus CVIFUNC avq8384_CenterSpan_Set (ViSession instrumentHandle,
                                         ViBoolean xaxisMode, ViReal64 center,
                                         ViReal64 span);

ViStatus CVIFUNC avq8384_StartStop_Set (ViSession instrumentHandle,
                                        ViBoolean xaxisMode, ViReal64 start,
                                        ViReal64 stop);

ViStatus CVIFUNC avq8384_Wavelength_Set (ViSession instrumentHandle,
                                         ViInt16 wavelengthMode, ViReal64 value,
                                         ViBoolean XAxisUnit);

ViStatus CVIFUNC avq8384_RefLvl_MenuSet (ViSession instrumentHandle,
                                         ViInt16 levelMode,
                                         ViReal64 refLevel,
                                         ViInt16 levelUnit,
                                         ViBoolean modeSwitch);

ViStatus CVIFUNC avq8384_RefLvl_HldToClr (ViSession instrumentHandle,
                                          ViBoolean holdType);

ViStatus CVIFUNC avq8384_RefLvlScl_MenuSet (ViSession instrumentHandle,
                                            ViBoolean display, ViInt16 scale);

ViStatus CVIFUNC avq8384_RefLvl_Set (ViSession instrumentHandle,
                                     ViReal64 refLevel, ViInt16 levelUnit);

ViStatus CVIFUNC avq8384_FuncAvg_Set (ViSession instrumentHandle,
                                      ViInt16 averageMode, ViInt16 avgCount);

ViStatus CVIFUNC avq8384_FuncReso_Set (ViSession instrumentHandle,
                                       ViReal64 resolution, ViInt16 unit);


ViStatus CVIFUNC avq8384_Swp_MenuSet (ViSession instrumentHandle,
                                      ViInt16 sweepMode, ViReal64 gateTime,
                                      ViInt16 gateTimeUnit, ViBoolean sync,
                                      ViReal64 delayTime, ViBoolean edge);

ViStatus CVIFUNC avq8384_WavelenCurs1_Set (ViSession instrumentHandle,
                                           ViBoolean lambda1,
                                           ViBoolean xaxisMode,
                                           ViReal64 setLambda1,
                                           ViInt16 unitLambda1);

ViStatus CVIFUNC avq8384_Wavelen_Curs2 (ViSession instrumentHandle,
                                        ViBoolean lambda2, ViBoolean xaxisMode,
                                        ViReal64 setLambda2, ViInt16 unitLambda2);

ViStatus CVIFUNC avq8384_LvlCurs1_Set (ViSession instrumentHandle,
                                       ViReal64 setLevel1, 
                                       ViInt16 unitLevel1,
                                       ViBoolean level1);

ViStatus CVIFUNC avq8384_LvlCurs2_Set (ViSession instrumentHandle,
                                       ViReal64 setLevel2, ViInt16 unitLevel2,
                                       ViBoolean level2);

ViStatus CVIFUNC avq8384_AppliSpcWid_MenuSet (ViSession instrumentHandle,
                                              ViBoolean specWidth,
                                              ViReal64 xdBParam,
                                              ViReal64 ydBParam, ViReal64 KParam,
                                              ViReal64 KRParam,
                                              ViReal64 xnmLevel,
                                              ViInt16 widthType,
                                              ViInt16 xnmLevelUnit);

ViStatus CVIFUNC avq8384_AppliNtchWid_MenuSet (ViSession instrumentHandle,
                                               ViInt16 notchWidth,
                                               ViReal64 level, ViReal64 width,
                                               ViInt16 widthUnit);

ViStatus CVIFUNC avq8384_AppliOptAmp_MenuSet (ViSession instrumentHandle,
                                              ViBoolean opticalAmp,
                                              ViBoolean opticalAmpMode,
                                              ViBoolean NFSelect,
                                              ViBoolean ASEFIT,
                                              ViBoolean spectrumDivision,
                                              ViReal64 KParameter2,
                                              ViReal64 maskedSpan,
                                              ViInt16 maskedSpanUnit,
                                              ViReal64 fittingSpan,
                                              ViInt16 fittingSpanUnit,
                                              ViReal64 filterDeltaL,
                                              ViInt16 filterDeltaLUnit,
                                              ViReal64 pinLoss,
                                              ViReal64 poutLoss,
                                              ViReal64 wdmYdBparam,
                                              ViBoolean WDMAseAuto);

ViStatus CVIFUNC avq8384_AppliWdmLst_MenuSet (ViSession instrumentHandle,
                                              ViBoolean WDMListDisp,
                                              ViInt16 WDMMode, ViBoolean listAll,
                                              ViReal64 WDMTresholdLevel);

ViStatus CVIFUNC avq8384_AppliWdmAse_Set (ViSession instrumentHandle,
                                          ViBoolean WDMAseAuto,
                                          ViInt16 aseFitting,
                                          ViReal64 manualAseLevel,
                                          ViInt16 levelUnit, ViReal64 maskedSpan,
                                          ViReal64 fittingSpan);

ViStatus CVIFUNC avq8384_AppliWdmMon_MenuSet (ViSession instrumentHandle,
                                              ViBoolean WDMMonitor,
                                              ViBoolean display,
                                              ViBoolean graphX, ViInt16 dataMode,
                                              ViInt16 currentSelectNo,
                                              ViInt16 measTime,
                                              ViReal64 timeInterval,
                                              ViReal64 WDMThresholdLevel);

ViStatus CVIFUNC avq8384_AppWdmMon_PfSet (ViSession instrumentHandle,
                                          ViBoolean limitJudgeenable,
                                          ViReal64 lambdaDriftLmt,
                                          ViReal64 levelUpperLimit,
                                          ViReal64 levelLowerLimit,
                                          ViInt16 levelLimitUnit,
                                          ViReal64 SNRLowerLimit);

ViStatus CVIFUNC avq8384_AppWdmMon_ArSet (ViSession instrumentHandle,
                                          ViInt16 ABSREL, ViReal64 nominalLevel,
                                          ViInt16 nominalLevelUnit,
                                          ViReal64 nominalSNR);

ViStatus CVIFUNC avq8384_AppliSelPin_MenuSet (ViSession instrumentHandle,
                                              ViBoolean selectPin,
                                              ViReal64 levelValue,
                                              ViInt16 levelUnit,
                                              ViReal64 wavelengthValue,
                                              ViInt16 wvLenUnit);


ViStatus CVIFUNC avq8384_SingleMeas_Start (ViSession instrumentHandle);

ViStatus CVIFUNC avq8384_MeasMode_Start (ViSession instrumentHandle,
                                         ViInt16 measurementMode);

ViStatus CVIFUNC avq8384_MeasCond_MenuSet (ViSession instrumentHandle,
                                           ViInt16 average, ViInt16 sweepMode,
                                           ViReal64 resolution,
                                           ViInt16 resolutionUnit,
                                           ViInt16 samplingPoint);

ViStatus CVIFUNC avq8384_Func_AutoSpanMode (ViSession instrumentHandle,
                                            ViInt16 autoSpan);

ViStatus CVIFUNC avq8384_PowMoni_MenuSet (ViSession instrumentHandle,
                                          ViBoolean powerMoniter, ViInt16 NMax,
                                          ViReal64 powerMonitorInterval);

ViStatus CVIFUNC avq8384_DspCtl_MenuSet (ViSession instrumentHandle,
                                         ViBoolean dual, ViBoolean grid,
                                         ViInt16 act, ViInt16 samplingPoint);

ViStatus CVIFUNC avq8384_DspCtrMlt_MenuSet (ViSession instrumentHandle,
                                            ViBoolean multiTrace,
                                            ViInt16 traceMax,
                                            ViInt16 currentTraceSet,
                                            ViBoolean autoTraceIncriment);

ViStatus CVIFUNC avq8384_DspCtrMlt_TraceCtr (ViSession instrumentHandle,
                                             ViInt16 operation,
                                             ViInt16 traceNumber);

ViStatus CVIFUNC avq8384_SpprImpose_OnOff (ViSession instrumentHandle,
                                           ViBoolean superImpose);

ViStatus CVIFUNC avq8384_Cursor_OnOff (ViSession instrumentHandle,
                                       ViBoolean cursor);

ViStatus CVIFUNC avq8384_CursDatMode_Sel (ViSession instrumentHandle,
                                          ViInt16 dataMode);

ViStatus CVIFUNC avq8384_Lambda2NxtPk (ViSession instrumentHandle,
                                       ViBoolean nextLambda2);

ViStatus CVIFUNC avq8384_NormPkNm_OnOff (ViSession instrumentHandle,
                                         ViBoolean peakNormalize);

ViStatus CVIFUNC avq8384_NormLoss_OnOff (ViSession instrumentHandle,
                                         ViBoolean loss);

ViStatus CVIFUNC avq8384_NormTrns_OnOff (ViSession instrumentHandle,
                                         ViBoolean trans);

ViStatus CVIFUNC avq8384_Normalise_Save (ViSession instrumentHandle,
                                         ViInt16 saveMenu);

ViStatus CVIFUNC avq8384_CalCalibInt_Start (ViSession instrumentHandle);

ViStatus CVIFUNC avq8384_CalCalibExt_Start (ViSession instrumentHandle,
                                            ViReal64 CALExt);

ViStatus CVIFUNC avq8384_CalLamdOfs_Set (ViSession instrumentHandle,
                                         ViReal64 lambdaOffset, ViInt16 unit);

ViStatus CVIFUNC avq8384_CalLvlOfs_Set (ViSession instrumentHandle,
                                        ViReal64 levelOffset);

ViStatus CVIFUNC avq8384_CalAutoAlign_Start (ViSession instrumentHandle);

ViStatus CVIFUNC avq8384_DevDevType_Sel (ViSession instrumentHandle,
                                         ViInt16 deviceType);

ViStatus CVIFUNC avq8384_DevFlp_OnOff (ViSession instrumentHandle,
                                       ViBoolean floppy);

ViStatus CVIFUNC avq8384_DevFlpFmt_Sel (ViSession instrumentHandle,
                                        ViInt16 floppyFormatting);

ViStatus CVIFUNC avq8384_DevBmp_MenuSet (ViSession instrumentHandle,
                                         ViInt16 saveImage,
                                         ViBoolean bitmapCompless);

ViStatus CVIFUNC avq8384_DevColorPatt_Set (ViSession instrumentHandle,
                                           ViInt16 colorPattern);

ViStatus CVIFUNC avq8384_DevExtPrt_MenuSet (ViSession instrumentHandle,
                                            ViInt16 extPrintMode,
                                            ViInt16 extPrintCommand);

ViStatus CVIFUNC avq8384_DevBuzzer_MenuSet (ViSession instrumentHandle,
                                            ViBoolean buzzer, ViBoolean warning,
                                            ViBoolean quietBeep);

ViStatus CVIFUNC avq8384_DevClock_Set (ViSession instrumentHandle, ViInt16 year,
                                       ViInt16 month, ViInt16 day, ViInt16 hour,
                                       ViInt16 minute);

ViStatus CVIFUNC avq8384_DevClock_OnOff (ViSession instrumentHandle,
                                         ViBoolean clock);

ViStatus CVIFUNC avq8384_DevMenuOut_OnOff (ViSession instrumentHandle,
                                           ViBoolean menuOutput);

ViStatus CVIFUNC avq8384_SrqCtrl_OnOff (ViSession instrumentHandle,
                                         ViBoolean SRQOut);

ViStatus CVIFUNC avq8384_StbMask_Set (ViSession instrumentHandle,
                                      ViInt16 maskValue);

ViStatus CVIFUNC avq8384_StbClear (ViSession instrumentHandle);

ViStatus CVIFUNC avq8384_HdData_OnOff (ViSession instrumentHandle,
                                       ViBoolean header);

ViStatus CVIFUNC avq8384_Terminator_Sel (ViSession instrumentHandle,
                                         ViInt16 terminator);

ViStatus CVIFUNC avq8384_DataSepa_Sel (ViSession instrumentHandle,
                                       ViInt16 dataSeparator);

ViStatus CVIFUNC avq8384_MessSepa_Sel (ViSession instrumentHandle,
                                       ViBoolean messageSeparator);

ViStatus CVIFUNC avq8384_DataOut_Sel (ViSession instrumentHandle,
                                      ViInt16 dataFormat, ViBoolean screenSelect);

ViStatus _VI_FUNC CVIFUNC avq8384_writeInstrData (ViSession instrumentHandle,
                                         ViChar writeBuffer[]);
ViStatus _VI_FUNC avq8384_readInstrData (ViSession instrSession,
                ViInt32 numberBytesToRead, ViChar _VI_FAR readBuffer[],
                ViPInt32 numBytesRead);

ViStatus CVIFUNC avq8384_MeasData (ViSession instrumentHandle, ViInt16 action,
                                   ViString filename);

ViStatus CVIFUNC avq8384_FuncCpoy_Start (ViSession instrumentHandle);

ViStatus CVIFUNC avq8384_FuncCopy_Feed (ViSession instrumentHandle);

ViStatus CVIFUNC avq8384_reset (ViSession instrumentHandle, ViBoolean resetType);

ViStatus CVIFUNC avq8384_ReadLimLinData (ViSession instrumentHandle,
                                         ViBoolean readData, ViInt16 selectData);

ViStatus CVIFUNC avq8384_SelfTest_Exe (ViSession instrumentHandle);

ViStatus _VI_FUNC avq8384_errorMessage (ViSession instrSession,
                ViStatus statusCode, ViChar _VI_FAR message[]);


ViStatus CVIFUNC avq8384_Waveform_Data (ViSession instrumentHandle,
                                        ViInt16 selecttype,
                                        short axisdataArray[]);

ViStatus CVIFUNC avq8384_holdMode_Data (ViSession instrumentHandle,
                                        ViInt16 *holdmode);

ViStatus CVIFUNC avq8384_WvDataNum_Data (ViSession instrumentHandle,
                                         ViInt16 *waveformDataNum);

ViStatus CVIFUNC avq8384_Waveform_Data_As (ViSession instrumentHandle,
                                           ViInt16 selecttype,
                                           ViReal64 axisdataArray[]);

ViStatus CVIFUNC avq8384_Waveform_Data_32bit (ViSession instrumentHandle,
                                              ViInt16 selecttype,
                                              float axisdataArray[]);

ViStatus CVIFUNC avq8384_Waveform_Data_64bit (ViSession instrumentHandle,
                                              ViInt16 selecttype,
                                              double axisdataArray[]);

ViStatus CVIFUNC avq8384_PeakSrcPWR_Data (ViSession instrumentHandle,
                                          ViReal64 *min, ViReal64 *max,
                                          ViReal64 *average);

ViStatus CVIFUNC avq8384_PeakSrcSpectrum_Data (ViSession instrumentHandle,
                                               ViReal64 *wavelength,
                                               ViReal64 *level);

ViStatus CVIFUNC avq8384_Cursor_Data (ViSession instrumentHandle,
                                      ViBoolean *powerMode, ViInt16 *cursorMode,
                                      ViInt16 *holdMode,
                                      ViInt16 *trendDataNumber, ViReal64 *data1,
                                      ViReal64 *data2, ViReal64 *data3,
                                      ViReal64 *data4, ViReal64 *data5,
                                      ViReal64 *data6, ViReal64 *data7,
                                      ViReal64 *data8);

ViStatus CVIFUNC avq8384_Halfwidth_Data (ViSession instrumentHandle,
                                         ViReal64 *LMCN, ViReal64 *LMHW,
                                         ViInt16 *NOSP);

ViStatus CVIFUNC avq8384_Notchwidth_Data (ViSession instrumentHandle,
                                          ViReal64 *LMCN, ViReal64 *LMHW);

ViStatus CVIFUNC avq8384_GainNf_Data (ViSession instrumentHandle, ViReal64 *LMCN,
                                      ViReal64 *GAIN, ViReal64 *PASE,
                                      ViReal64 *NF);

ViStatus CVIFUNC avq8384_OptAmpWdmResult1_Data (ViSession instrumentHandle,
                                                ViReal64 lambdaArr[],
                                                ViReal64 gainArr[],
                                                ViReal64 paseArr[],
                                                ViReal64 NFArr[],
                                                ViInt16 *peakCount);

ViStatus CVIFUNC avq8384_OptAmpWdmResult2_Data (ViSession instrumentHandle,
                                                ViReal64 lambdaArr[],
                                                ViReal64 poutArr[],
                                                ViReal64 gainArr[],
                                                ViReal64 paseArr[],
                                                ViReal64 NFArr[],
                                                ViInt16 *peakCount);


ViStatus CVIFUNC avq8384_PowerMoni_Data (ViSession instrumentHandle,
                                         ViReal64 *LVLG);

ViStatus CVIFUNC avq8384_PowerMoniNmax_Data (ViSession instrumentHandle,
                                             ViInt16 *nmax);

ViStatus CVIFUNC avq8384_PwrMoniMode_Data (ViSession instrumentHandle,
                                           ViInt16 *mode);

ViStatus CVIFUNC avq8384_GainNfTotAse_Data (ViSession instrumentHandle,
                                            ViReal64 *LMCN, ViReal64 *GAIN,
                                            ViReal64 *PASE, ViReal64 *NF,
                                            ViReal64 *PSPW);

ViStatus CVIFUNC avq8384_WdmPkNum_Data (ViSession instrumentHandle,
                                        ViInt16 *WDMPeakNum);

ViStatus CVIFUNC avq8384_WdmListOnOff_Data (ViSession instrumentHandle,
                                            ViBoolean *WDMListState);

ViStatus CVIFUNC avq8384_ListDatNum_Data (ViSession instrumentHandle,
                                          ViInt16 *listDataNumber);

ViStatus CVIFUNC avq8384_WdmListOn_Data (ViSession instrumentHandle,
                                         ViInt16 *WDMMode, ViInt16 *listNum,
                                         ViReal64 array1[], ViReal64 array2[],
                                         ViReal64 array3[], ViReal64 array4[],
                                         ViReal64 array5[]);

ViStatus CVIFUNC avq8384_WdmMon_Data (ViSession instrumentHandle,
                                      ViInt16 timeData, ViInt16 *passFail,
                                      ViInt16 *peakCount, ViReal64 XData[],
                                      ViReal64 level[], ViReal64 SNR[],
                                      ViReal64 XJugde[], ViReal64 LJudge[],
                                      ViReal64 SJudge[]);

ViStatus CVIFUNC avq8384_WdmMonNum_Data (ViSession instrumentHandle,
                                         ViInt16 *number);

ViStatus CVIFUNC avq8384_WdmMonLimPf_Data (ViSession instrumentHandle,
                                           ViInt16 *result);



ViStatus CVIFUNC avq8384_LimLinePf_Data (ViSession instrumentHandle,
                                         ViInt16 *result);

ViStatus CVIFUNC avq8384_AseStPoint_Data (ViSession instrumentHandle,
                                          ViInt16 *startPoint);

ViStatus CVIFUNC avq8384_AseNum_Data (ViSession instrumentHandle,
                                      ViInt16 *numberDemand);

ViStatus CVIFUNC avq8384_AseFit_Data (ViSession instrumentHandle,
                                      ViReal64 aseFitDataOut[]);

ViStatus CVIFUNC avq8384_AseFit16Bit_Data (ViSession instrumentHandle,
                                           short aseFitDataOut[]);

ViStatus CVIFUNC avq8384_AseFit64bit_Data (ViSession instrumentHandle,
                                           ViReal64 aseFitDataOut[]);

ViStatus CVIFUNC avq8384_AseFit32bit_Data (ViSession instrumentHandle,
                                           float aseFitDataOut[]);

ViStatus CVIFUNC avq8384_DevClock_Data (ViSession instrumentHandle,
                                        ViInt16 *year, ViInt16 *month,
                                        ViInt16 *day, ViInt16 *hour,
                                        ViInt16 *minute, ViInt16 *second);

ViStatus CVIFUNC avq8384_InstrID_Data (ViSession instrumentHandle,
                                       ViChar company[], ViChar machineID[],
                                       ViChar serealNo[], ViChar rev1[],
                                       ViChar rev2[]);

ViStatus CVIFUNC avq8384_SelfTest_Data (ViSession instrumentHandle,
                                        ViInt16 *selfTestResult);

ViStatus CVIFUNC avq8384_Label_Set (ViSession instrumentHandle,
                                    ViString labelString);

ViStatus _VI_FUNC avq8384_close (ViSession instrSession);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
